==> qt5-base-debuginfo-5.9.3-2.tar.xz: usr/src/debug/qt5-base-5.9.3-2/examples/sql/books/.rcc/qrc_books.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.9.3-2.x86_64/src/qtbase-opensource-src-5.9.3/examples/sql/books/images/star.png
  0x0,0x0,0x3,0xe,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x11,0x0,0x0,0xb,0x11,
  0x1,0x7f,0x64,0x5f,0x91,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xd4,0x9,
  0x3,0x12,0x11,0x8,0x18,0x7e,0xe5,0x3a,0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,
  0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,0xa7,0x93,0x0,0x0,0x2,0x9b,0x49,0x44,
  0x41,0x54,0x38,0xcb,0x63,0x98,0x3a,0x63,0x1e,0x23,0x3a,0xe6,0xe5,0x64,0xcf,0x17,
  0x12,0x12,0x16,0xc4,0x26,0x87,0x8e,0x19,0xb0,0x9,0x76,0xc6,0x18,0xb7,0x78,0xea,
  0x8b,0xcd,0x9c,0x3d,0x6f,0x9,0x69,0x6,0x2c,0x58,0x34,0x8f,0xf1,0xd2,0xa5,0x99,
  0x4c,0xb9,0xa1,0x16,0xc5,0xc7,0xbb,0xed,0xff,0xa,0xf2,0xb2,0x3b,0x4d,0x9f,0xb5,
  0x90,0x38,0x3,0x16,0x2c,0x9a,0xcb,0xf8,0xe0,0xde,0x4,0x96,0xc7,0xf,0xdb,0x79,
  0xe7,0x4d,0x4f,0xc8,0xfb,0x76,0xbf,0xe5,0xff,0xb4,0xa,0x9b,0x9b,0x79,0x85,0x31,
  0xdc,0xd3,0x67,0x2d,0x82,0x6b,0x98,0x33,0x7f,0x29,0xe3,0x6c,0x20,0x46,0x31,0x60,
  0xca,0xf4,0x79,0x8c,0xd7,0xae,0x4d,0x67,0x2,0x69,0x7e,0xf2,0xa8,0x59,0xe1,0xd2,
  0xa5,0xfa,0xdc,0x5f,0x9f,0x37,0xfd,0xff,0x78,0xbf,0xea,0x7f,0x45,0x96,0x6d,0x97,
  0x81,0x81,0x3e,0x27,0x33,0x33,0x8b,0xa5,0x9e,0x38,0x67,0x69,0xb8,0x9e,0xc0,0x66,
  0x26,0x26,0xa6,0x44,0x14,0x3,0x26,0x4e,0x9d,0xc7,0x78,0xef,0xde,0x44,0x96,0x27,
  0xf,0x5b,0x45,0x9f,0x3e,0x6a,0xd6,0xbd,0x75,0xb3,0x22,0xef,0xd7,0xb7,0x3d,0xff,
  0xbe,0x7f,0xe8,0xfb,0x7f,0x7e,0x53,0xcc,0xef,0x5,0xc5,0xea,0x9f,0x4e,0x4f,0x51,
  0xfb,0x7f,0xba,0x4d,0xed,0xbf,0x87,0x1a,0xef,0x6e,0x35,0x2d,0x1d,0x56,0x14,0x3,
  0x66,0xcf,0x5b,0xce,0xa8,0xa4,0xa9,0x21,0x5b,0x57,0xed,0x9b,0x7d,0xef,0x4a,0xcb,
  0xce,0x77,0xaf,0x26,0x7f,0xfa,0xfe,0x65,0xc9,0xff,0xef,0x1f,0xfa,0xff,0xbf,0xbf,
  0x95,0xf2,0xff,0xc9,0x5e,0x83,0xff,0x57,0x17,0xaa,0xfd,0x6f,0x74,0x12,0x7b,0xc4,
  0xc7,0xc7,0x2f,0x8e,0x12,0x6,0x59,0xb9,0x85,0xcc,0xb2,0x82,0x1c,0xf3,0xa7,0x44,
  0xab,0xfe,0xfa,0xbe,0x25,0xe2,0xff,0x8f,0x67,0x6d,0xff,0x7f,0x7c,0x9a,0x8,0xd6,
  0xfc,0xf5,0x59,0xcd,0xff,0xd7,0xe7,0xfc,0xfe,0xdf,0xde,0xa0,0xf5,0x7f,0x45,0x94,
  0xec,0x4f,0x16,0x16,0x56,0xeb,0x69,0x33,0xe7,0xa3,0x6,0xe2,0xe4,0x69,0x73,0x18,
  0xe7,0x2f,0x5a,0xc1,0xc8,0xce,0xc1,0x69,0x10,0xe5,0xa8,0xd2,0xbe,0xa6,0xcd,0xe7,
  0xf6,0xc3,0x6d,0x99,0xff,0x7e,0x5e,0x28,0xf8,0xff,0xe1,0x6a,0xe0,0xff,0x17,0x47,
  0x4c,0xff,0xdf,0xdf,0xae,0xf6,0xbf,0xc2,0x5d,0xf4,0xba,0x9a,0x9a,0x6,0x1b,0x46,
  0x2c,0x0,0x1,0x23,0x32,0xe6,0xe6,0xe6,0x60,0x51,0xd6,0x94,0x31,0x5f,0xde,0xe4,
  0x71,0xfb,0xc3,0x79,0xd3,0xff,0x1b,0x8a,0x54,0xff,0xbf,0x3f,0x60,0xff,0xff,0xdc,
  0x6c,0xe5,0xff,0xea,0xc2,0x1c,0x39,0xd3,0x67,0x2d,0xc0,0x69,0x0,0x13,0x10,0x8b,
  0x3,0xb1,0x3f,0x10,0xe7,0xf5,0x16,0xd8,0xde,0xf8,0x70,0xc6,0xe4,0xbf,0x9d,0x3c,
  0xf7,0x74,0x7f,0x43,0xe9,0x95,0xb7,0x96,0xd9,0xff,0x9b,0x9c,0x2c,0xfd,0x4e,0x40,
  0x40,0x48,0x14,0x9b,0x1,0x4c,0x50,0x2c,0x6,0xc4,0x19,0x40,0x7c,0x22,0x3b,0xca,
  0xf0,0xe7,0xe9,0xf9,0x6,0xff,0x81,0xec,0x3,0x40,0xbc,0x5e,0x82,0x9f,0xf3,0xf6,
  0x9e,0x1a,0xf3,0x5f,0x61,0x7a,0x82,0x33,0x50,0xd2,0x1,0x54,0x23,0x33,0x10,0xb,
  0x0,0xb1,0x1e,0x10,0x17,0x3,0xf1,0xd1,0xa8,0x40,0xdd,0x9f,0xad,0x9,0x4a,0x20,
  0x3,0xfe,0x0,0xf1,0x37,0x20,0x3e,0xf,0xb4,0x6b,0x66,0xb9,0xa7,0xea,0xd,0x7d,
  0x69,0x3e,0x23,0x64,0x3,0xb4,0x80,0x38,0x8,0x88,0x6b,0x81,0x78,0x9,0xd4,0xc6,
  0x1b,0x11,0x61,0x6,0xdf,0xec,0x94,0xb8,0xdf,0x3,0xd9,0x3b,0x81,0x78,0x1a,0x10,
  0xf7,0x82,0xd4,0xb0,0xb2,0xb1,0x47,0xf9,0xda,0x99,0x3a,0x4c,0x9d,0x39,0x9f,0x9,
  0x66,0x80,0xe,0x10,0x3b,0x2,0xb1,0x13,0x10,0x5b,0x0,0xb1,0x1,0x10,0x7,0x6,
  0x7b,0x68,0x9c,0x2,0xd2,0x6b,0xa0,0x86,0x8b,0x0,0x31,0x17,0x10,0xf3,0x80,0xb0,
  0x88,0x88,0x28,0xcb,0x2c,0x68,0x46,0x43,0xf6,0x2,0x8,0xb3,0x0,0x31,0x2b,0x10,
  0x4b,0x31,0x32,0x32,0xe4,0x1,0x69,0x37,0x20,0x96,0x1,0x62,0x36,0xa8,0x38,0xb,
  0x54,0x3d,0x63,0x57,0xef,0x24,0xb0,0x1,0x0,0xce,0x6f,0x7b,0xf5,0x55,0x4c,0xf0,
  0xac,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // images
  0x0,0x6,
  0x7,0x3,0x7d,0xc3,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x73,
    // star.png
  0x0,0x8,
  0xa,0x85,0x58,0x7,
  0x0,0x73,
  0x0,0x74,0x0,0x61,0x0,0x72,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/images
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/images/star.png
  0x0,0x0,0x0,0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0xc3,0x40,0xd9,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_books)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_books)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_books)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_books)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_books)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_books)(); }
   } dummy;
}

==> qt5-base-debuginfo-5.9.4-1.tar.xz: usr/src/debug/qt5-base-5.9.4-1/examples/sql/books/.rcc/qrc_books.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.4
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.9.4-1.i686/src/qtbase-opensource-src-5.9.4/examples/sql/books/images/star.png
  0x0,0x0,0x3,0xe,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x11,0x0,0x0,0xb,0x11,
  0x1,0x7f,0x64,0x5f,0x91,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xd4,0x9,
  0x3,0x12,0x11,0x8,0x18,0x7e,0xe5,0x3a,0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,
  0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,0xa7,0x93,0x0,0x0,0x2,0x9b,0x49,0x44,
  0x41,0x54,0x38,0xcb,0x63,0x98,0x3a,0x63,0x1e,0x23,0x3a,0xe6,0xe5,0x64,0xcf,0x17,
  0x12,0x12,0x16,0xc4,0x26,0x87,0x8e,0x19,0xb0,0x9,0x76,0xc6,0x18,0xb7,0x78,0xea,
  0x8b,0xcd,0x9c,0x3d,0x6f,0x9,0x69,0x6,0x2c,0x58,0x34,0x8f,0xf1,0xd2,0xa5,0x99,
  0x4c,0xb9,0xa1,0x16,0xc5,0xc7,0xbb,0xed,0xff,0xa,0xf2,0xb2,0x3b,0x4d,0x9f,0xb5,
  0x90,0x38,0x3,0x16,0x2c,0x9a,0xcb,0xf8,0xe0,0xde,0x4,0x96,0xc7,0xf,0xdb,0x79,
  0xe7,0x4d,0x4f,0xc8,0xfb,0x76,0xbf,0xe5,0xff,0xb4,0xa,0x9b,0x9b,0x79,0x85,0x31,
  0xdc,0xd3,0x67,0x2d,0x82,0x6b,0x98,0x33,0x7f,0x29,0xe3,0x6c,0x20,0x46,0x31,0x60,
  0xca,0xf4,0x79,0x8c,0xd7,0xae,0x4d,0x67,0x2,0x69,0x7e,0xf2,0xa8,0x59,0xe1,0xd2,
  0xa5,0xfa,0xdc,0x5f,0x9f,0x37,0xfd,0xff,0x78,0xbf,0xea,0x7f,0x45,0x96,0x6d,0x97,
  0x81,0x81,0x3e,0x27,0x33,0x33,0x8b,0xa5,0x9e,0x38,0x67,0x69,0xb8,0x9e,0xc0,0x66,
  0x26,0x26,0xa6,0x44,0x14,0x3,0x26,0x4e,0x9d,0xc7,0x78,0xef,0xde,0x44,0x96,0x27,
  0xf,0x5b,0x45,0x9f,0x3e,0x6a,0xd6,0xbd,0x75,0xb3,0x22,0xef,0xd7,0xb7,0x3d,0xff,
  0xbe,0x7f,0xe8,0xfb,0x7f,0x7e,0x53,0xcc,0xef,0x5,0xc5,0xea,0x9f,0x4e,0x4f,0x51,
  0xfb,0x7f,0xba,0x4d,0xed,0xbf,0x87,0x1a,0xef,0x6e,0x35,0x2d,0x1d,0x56,0x14,0x3,
  0x66,0xcf,0x5b,0xce,0xa8,0xa4,0xa9,0x21,0x5b,0x57,0xed,0x9b,0x7d,0xef,0x4a,0xcb,
  0xce,0x77,0xaf,0x26,0x7f,0xfa,0xfe,0x65,0xc9,0xff,0xef,0x1f,0xfa,0xff,0xbf,0xbf,
  0x95,0xf2,0xff,0xc9,0x5e,0x83,0xff,0x57,0x17,0xaa,0xfd,0x6f,0x74,0x12,0x7b,0xc4,
  0xc7,0xc7,0x2f,0x8e,0x12,0x6,0x59,0xb9,0x85,0xcc,0xb2,0x82,0x1c,0xf3,0xa7,0x44,
  0xab,0xfe,0xfa,0xbe,0x25,0xe2,0xff,0x8f,0x67,0x6d,0xff,0x7f,0x7c,0x9a,0x8,0xd6,
  0xfc,0xf5,0x59,0xcd,0xff,0xd7,0xe7,0xfc,0xfe,0xdf,0xde,0xa0,0xf5,0x7f,0x45,0x94,
  0xec,0x4f,0x16,0x16,0x56,0xeb,0x69,0x33,0xe7,0xa3,0x6,0xe2,0xe4,0x69,0x73,0x18,
  0xe7,0x2f,0x5a,0xc1,0xc8,0xce,0xc1,0x69,0x10,0xe5,0xa8,0xd2,0xbe,0xa6,0xcd,0xe7,
  0xf6,0xc3,0x6d,0x99,0xff,0x7e,0x5e,0x28,0xf8,0xff,0xe1,0x6a,0xe0,0xff,0x17,0x47,
  0x4c,0xff,0xdf,0xdf,0xae,0xf6,0xbf,0xc2,0x5d,0xf4,0xba,0x9a,0x9a,0x6,0x1b,0x46,
  0x2c,0x0,0x1,0x23,0x32,0xe6,0xe6,0xe6,0x60,0x51,0xd6,0x94,0x31,0x5f,0xde,0xe4,
  0x71,0xfb,0xc3,0x79,0xd3,0xff,0x1b,0x8a,0x54,0xff,0xbf,0x3f,0x60,0xff,0xff,0xdc,
  0x6c,0xe5,0xff,0xea,0xc2,0x1c,0x39,0xd3,0x67,0x2d,0xc0,0x69,0x0,0x13,0x10,0x8b,
  0x3,0xb1,0x3f,0x10,0xe7,0xf5,0x16,0xd8,0xde,0xf8,0x70,0xc6,0xe4,0xbf,0x9d,0x3c,
  0xf7,0x74,0x7f,0x43,0xe9,0x95,0xb7,0x96,0xd9,0xff,0x9b,0x9c,0x2c,0xfd,0x4e,0x40,
  0x40,0x48,0x14,0x9b,0x1,0x4c,0x50,0x2c,0x6,0xc4,0x19,0x40,0x7c,0x22,0x3b,0xca,
  0xf0,0xe7,0xe9,0xf9,0x6,0xff,0x81,0xec,0x3,0x40,0xbc,0x5e,0x82,0x9f,0xf3,0xf6,
  0x9e,0x1a,0xf3,0x5f,0x61,0x7a,0x82,0x33,0x50,0xd2,0x1,0x54,0x23,0x33,0x10,0xb,
  0x0,0xb1,0x1e,0x10,0x17,0x3,0xf1,0xd1,0xa8,0x40,0xdd,0x9f,0xad,0x9,0x4a,0x20,
  0x3,0xfe,0x0,0xf1,0x37,0x20,0x3e,0xf,0xb4,0x6b,0x66,0xb9,0xa7,0xea,0xd,0x7d,
  0x69,0x3e,0x23,0x64,0x3,0xb4,0x80,0x38,0x8,0x88,0x6b,0x81,0x78,0x9,0xd4,0xc6,
  0x1b,0x11,0x61,0x6,0xdf,0xec,0x94,0xb8,0xdf,0x3,0xd9,0x3b,0x81,0x78,0x1a,0x10,
  0xf7,0x82,0xd4,0xb0,0xb2,0xb1,0x47,0xf9,0xda,0x99,0x3a,0x4c,0x9d,0x39,0x9f,0x9,
  0x66,0x80,0xe,0x10,0x3b,0x2,0xb1,0x13,0x10,0x5b,0x0,0xb1,0x1,0x10,0x7,0x6,
  0x7b,0x68,0x9c,0x2,0xd2,0x6b,0xa0,0x86,0x8b,0x0,0x31,0x17,0x10,0xf3,0x80,0xb0,
  0x88,0x88,0x28,0xcb,0x2c,0x68,0x46,0x43,0xf6,0x2,0x8,0xb3,0x0,0x31,0x2b,0x10,
  0x4b,0x31,0x32,0x32,0xe4,0x1,0x69,0x37,0x20,0x96,0x1,0x62,0x36,0xa8,0x38,0xb,
  0x54,0x3d,0x63,0x57,0xef,0x24,0xb0,0x1,0x0,0xce,0x6f,0x7b,0xf5,0x55,0x4c,0xf0,
  0xac,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // images
  0x0,0x6,
  0x7,0x3,0x7d,0xc3,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x73,
    // star.png
  0x0,0x8,
  0xa,0x85,0x58,0x7,
  0x0,0x73,
  0x0,0x74,0x0,0x61,0x0,0x72,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/images
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/images/star.png
  0x0,0x0,0x0,0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x60,0xfd,0xbe,0xb8,0xd8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_books)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_books)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_books)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_books)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_books)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_books)(); }
   } dummy;
}
